@@ -1,7 +1,5 @@
 """
-Type annotations for sso-admin service literal definitions.
-
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/literals.html)
+Main interface for sso-admin service literal definitions.
 
 Usage::
 
